import{B as l}from"./BaseLayout-CxJFzA0o.js";import{C as p}from"./ContentLayout-D8pfLPvb.js";import{e as f,ak as _,b as i,G as g,a4 as b,n as r,g as s,w as m,v as y,j as w}from"./jwt-decode.esm-Qs17A51Z.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-3JNT5EFn.js";import{u as z}from"./projectsStore-Bv7zv6Ov.js";import"./router-CAO61PD6.js";import"./ts.worker-BCWFpXJQ.js";import"./index-Cva6BoLy.js";import"./member-DNx2SAQd.js";import"./organization-CcZsiAel.js";import"./project-BOFVzXrP.js";import"./tables-B27IV4tt.js";import"./string-BNR4K1kf.js";import"./cascaderStore-5XlVZbNo.js";import"./organizationSwitcher-Dyx5sxXM.js";import"./ant-design-Dh1lPcGN.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="694419ca-b3b4-4713-8d57-888d34370198",t._sentryDebugIdIdentifier="sentry-dbid-694419ca-b3b4-4713-8d57-888d34370198")}catch{}})();const P=f({__name:"Organization",setup(t){const e=_(),o=z(),n=i(()=>e.params.organizationId);g(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const u=i(()=>o.fetchedState?.organization),d=i(()=>u.value?.billingMetadata);return(a,h)=>{const c=b("RouterView");return s(),r(l,null,{content:m(()=>[y(p,null,{default:m(()=>[d.value?(s(),r(v,{key:0,"billing-metadata":d.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(c,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-BSbdYUtM.js.map
