import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-DMMCkSlW.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-Qs17A51Z.js";import{u as a}from"./projectStore-B_e-GYGu.js";import"./router-CAO61PD6.js";import"./ts.worker-BCWFpXJQ.js";import"./fetch-ekDLEGXt.js";import"./tables-B27IV4tt.js";import"./string-BNR4K1kf.js";import"./SaveButton-CL3_jkme.js";import"./ExclamationCircleOutlined-DouPigSA.js";import"./CrudView-C3VTFDLW.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DscEuWpv.js";import"./constants-Dzlhihhr.js";import"./url-rKVnp5kh.js";import"./PhDotsThreeVertical.vue-CK8EGT9G.js";import"./index-B0-noClS.js";import"./asyncComputed-BO-Gc5RL.js";import"./PhPencil.vue-DKAwZIF6.js";import"./useCodebaseEvents-D2VWOIEg.js";import"./contracts.generated-i3jLu81Q.js";import"./index-Cva6BoLy.js";import"./project-BOFVzXrP.js";import"./organizationSwitcher-Dyx5sxXM.js";import"./organization-CcZsiAel.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="4dfbe3ca-718a-46be-9632-4b1af1f7c4ab",o._sentryDebugIdIdentifier="sentry-dbid-4dfbe3ca-718a-46be-9632-4b1af1f7c4ab")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(f,c)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-DPH96i5H.js.map
