import{N as c}from"./Navbar-w0OdXKMT.js";import{e as d,ak as u,b as a,l,a4 as f,f as _,g as y,v as p,k as I,aO as v}from"./jwt-decode.esm-Qs17A51Z.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-BfwN194p.js";import"./constants-Dzlhihhr.js";import"./PhCaretDown.vue-D2kySIi_.js";import"./PhPencilSimple.vue-XA-5sbqB.js";import"./router-CAO61PD6.js";import"./ts.worker-BCWFpXJQ.js";import"./organization-CcZsiAel.js";import"./tables-B27IV4tt.js";import"./string-BNR4K1kf.js";import"./keyboard-C9o5bR_6.js";import"./os-CNXAnyl0.js";import"./projectStore-B_e-GYGu.js";import"./project-BOFVzXrP.js";import"./organizationSwitcher-Dyx5sxXM.js";import"./cascaderStore-5XlVZbNo.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CzydH_5U.js";import"./member-DNx2SAQd.js";import"./index-CKYKfX_s.js";import"./index-4sj8W_Sz.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-B8OGdIJc.js";import"./PhNotePencil.vue-CcY_ClRE.js";import"./PhSignOut.vue-36kV_oSU.js";import"./index-B0-noClS.js";import"./index-CdrrIqna.js";import"./PhPlus.vue-CXhyO6tl.js";import"./omniChatStore-DfJ_qHkP.js";import"./files-vBnWZd08.js";import"./contracts.generated-i3jLu81Q.js";import"./runnerData-BATv2Xk_.js";import"./url-rKVnp5kh.js";import"./colorHelpers-CIbhXMJi.js";import"./uuid-NVpBwxGG.js";import"./PhCopySimple.vue-CAPcIT9G.js";import"./PhSparkle.vue-Bz71i3kz.js";import"./index-k0IEDtfF.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d1f953e6-9af3-4e3e-9c79-11a028ce3983",e._sentryDebugIdIdentifier="sentry-dbid-d1f953e6-9af3-4e3e-9c79-11a028ce3983")}catch{}})();const g={class:"console-layout"},b={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return y(),_("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",b,[p(r)])])}}}),io=v(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-B9jjiYHz.js.map
